//  Douglas M. Hurst
//  8912 Spur Road
//  Springfield, VA 22153
//  CompuServe 72767,1163
//
//  BARPRINT - is a test program that produces a 3 of 9 and a 
//  USPS zip bar code on an HP LaserJet Plus (or newer) or 
//  compatible printer, WITHOUT THE REQUIREMENT OF AN EXTERNAL
//  LIBRARY OR CARTRIDGE.  You must link this program with either 
//  BARS.LIB (small code) or BARL.LIB (large code).  
//
//  This program takes as its arguments two or three strings.
//  The first string should be a code for the 3 of 9 output,
//  and should take a form similar to the following:
//
//                             ZYQ9217250001
//
//  The 3 of 9 bar code requires an asterisk on each end of 
//  string.  The function hp_printbar39() will take care of 
//  this prior to printing.  The code sent to the printer 
//  in this case would be:
//
//                            *ZYQ9217250001*
//
//  The program will also produce USPS 5, 9 and the yet to be 
//  fully implemented advanced zip code bar codes.  This will
//  be the second argument to the command line and should
//  take the form:
//
//                              22153  or 221531243
//
//  Of course, you can supply any numbers you want.
//
//  As with the 3 of 9 codes, the postal bar codes require 
//  an asterisk at each end of the code, as well as a
//  computed 'check digit' between the last digit and the
//  closing asterisk. This is all handled by the function 
//  hp_printbarzip().  The check digit is computed by 
//  adding all the numbers of the supplied zip code, 
//  obtaining the modulus of a division of this sum by 10,
//  and then subtracting the resulting remainder from 10.
//  In the 9 digit example above, the check digit would be 
//  computed as:
//
//                        2+2+1+5+3+1+2+4+3 = 23
//
//                            23 % 10 = 3
//
//                            10 - 3 = 7
//
//  So the number sent to the printer would be
//
//                           *2215312437*
//
//
//  If a third command line paramter is supplied, it should
//  take the following form:
//
//                          131 Spur Road
//                          P.O. Box 234
//                          Rural Route 3
//
//  or somthing similar.
//
//  The USPS' new advanced system will use the last two
//  digits of a street address, post office box or rural
//  route to further define the mail sorting process.
//  If there is only one digit available, as in rural route
//  example above, the lone digit will be preceeded by a 
//  zero.  Using the previous 9 digit example and the top 
//  address above of 131 Spur Road, the check digit would 
//  be computed as
//
//                       2+2+1+5+3+1+2+4+3+3+1 = 27
//
//                            27 % 10 = 7
//
//                            10 - 7 = 3
//
//  So the number sent to the printer would be
//
//                          *221531243313*
//
#include "bar.h"

void main(int, char **);
void usage();

void main(int argc, char **argv)
{
  int i,j,k;

  argc--;
  if (!argc)
    usage();
  else
  {
    argv++;
    fprintf(stdprn,HP_INIT,PORTRAIT_FLAG);

    if (hp_printbar39(stdprn,25,20,*argv))
      printf("Non-Bar39 character in string.\n");

    argc--;
    if (!argc)
      usage();
    else{
      argv++;
      if (argc < 2)
      {
        if (hp_printbarzip(stdprn,25,30,*argv,NULLP))
          printf("Non-zip character in string.\n");
      }
      else
      {
        if (hp_printbarzip(stdprn,25,40,*argv,argv[1]))
          printf("Non-zip character in string.\n");
      }
    }
  }

  // MAY OR MAY NOT BE REQUIRED.  IT SIMPLY RESETS THE LASERJET
  // 
  fprintf(stdprn,HP_DEINIT);
}

void usage()
{
  printf("USAGE: BARPRINT <3 of 9 code string> <zip string> [<address>]\n");
  exit(1);
}
